Demo of atsphinx-typst
======================

:date: 2025-06-30
:version: v0.0.0


This is one of Sphinx extension that provides custom builder
to generate Typst format text.
You can generate PDF file of document more easy than latex builders by Sphinx.

Features
--------

* Provide "typst" and "typstpdf" builders.

  * "typst" builder translates from doctree to Typst format document.
  * "typstpdf" builder generates PDF files
    from document generated by "typst" builder, using typst binary.

* Datamodel for Typst using in Python.


Supporting syntax
-----------------

* All of docutils nodes.
* All of nodes for Spinx bundled extensions.

Milestone
---------

#. v0.1

   * It can generate PDF file of this project's documentation.
   * It supports syntax of docutils standard.

#. v1.0

   * It can generate PDF file of sphinx-revealjs's documentation.
   * It can generate private tech-ZINE.
